<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>{% block title %}Salaora{% endblock title %} v{{ VERSION }}</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.1/dist/css/bootstrap.min.css" rel="stylesheet">
</head>
<body class="container">
    <nav class="navbar navbar-expand-lg navbar-light border-bottom mb-5">
      <div class="container-fluid">
        <a class="navbar-brand" href="{% url 'vehicles' %}"><h1>Salaora</h1></a>
        <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNavDropdown" aria-controls="navbarNavDropdown" aria-expanded="false" aria-label="Toggle navigation">
          <span class="navbar-toggler-icon"></span>
        </button>
        <div class="collapse navbar-collapse" id="navbarNavDropdown">
          <ul class="navbar-nav me-auto">
            <li class="nav-item">
              <a class="nav-link {% if request.resolver_match.url_name == 'vehicles' %}active{% endif %}" href="{% url 'vehicles' %}">Vehicles</a>
            </li>
            <li class="nav-item">
              <a class="nav-link {% if request.resolver_match.url_name == 'crud_reservation' %}active{% endif %}" href="{% url 'crud_reservation' %}">Create Reservation</a>
            </li>
            <li class="nav-item">
              <a class="nav-link {% if request.resolver_match.url_name == 'reservations' %}active{% endif %}" href="{% url 'reservations' %}">Reservations</a>
            </li>
          </ul>
          <ul class="nav">
            <li class="nav-item"><a href="{% url 'admin:index' %}" class="nav-link link-dark px-2">Login</a></li>
          </ul>
        </div>
      </div>
    </nav>

  <div class="p-3 shadow">{% block page_content %}{% endblock page_content %}</div>
</body>
</html>
