{% extends "base.html" %}

{% block page_content %}
    <div class="container w-75 py-5">
        <h2>Bulk Create Vehicles</h2>
        <p class="py-2">No vehicles are registered yet. Consider creating some...</p>
            <form action="{% url 'bulk_create_vehicles' %}" method="post" class="row g-3 border py-3">
            {% csrf_token %}
            <div class="col-12">
                <label for="inputCsvData">CSV Data</label>
                <textarea class="form-control" name="csv_data" id="inputCsvData" rows="3" placeholder="Paste csv data here..."></textarea>
            </div>

              <div class="col-12">
                <button type="submit" class="btn btn-primary">Bulk Create</button>
              </div>
            </form>

    </div>
{% endblock page_content %}
